import { insertButton, addFloat } from './button.js';
import { options, isActive, turnOn, turnOff, showPrevious, showNext } from './main.js';
import { showPopup, hidePopup } from './popup.js';

export function insertMenu() {
	options.button ??= insertButton(options);
	options.control.insertAdjacentHTML('beforeend', `
<div id="vocabMenu" role="menu" aria-label="Vocab options" tabindex="-1">
	<button class="vocabButton" name="previous" role="menuitem" title="Previous tip"/>
	<button class="vocabButton" name="next" role="menuitem" title="Next tip"/>
	<button class="vocabButton" name="help" role="menuitem" title="Help"/>
	${options.speaker ? '<button class="vocabButton" name="audio" role="menuitemcheckbox" title="Toggle audio" aria-checked="false"/>' : ''}
	<button class="vocabButton" name="off" aria-hidden="true" title="Turn Vocab off"/>
</div>
	`);
	options.menu = options.control.lastElementChild;
	if (options.container) addFloat(options.menu, options.position);
	options.menu.addEventListener('click', handleClick);
	document.body.classList.remove('vocabLoading');
}

function handleClick(e) {
	e.preventDefault();
	const btn = e.target.closest('button');
	switch (btn?.name) {
		case 'toggle':
			isActive() ? turnOff() : turnOn();
			break;
		case 'previous':
			showPrevious();
			break;
		case 'next':
			showNext();
			break;
		case 'help':
			if (btn.classList.contains('active')) {
				btn.classList.remove('active');
				hidePopup();
			} else {
				btn.classList.add('active');
				showHelp(btn);
			}
			break;
		case 'audio':
			if (btn.getAttribute('aria-checked') === 'true') {
				btn.setAttribute('aria-checked', 'false');
				btn.title = 'Play audio';
				options.audio = false;
			} else {
				btn.setAttribute('aria-checked', 'true');
				btn.title = 'Disable audio';
				options.player ??= new Audio();
				options.audio = true;
			}
			break;
		case 'off':
			turnOff();
			break;
	}
}

function showHelp(target) {
	const meta = /Macintosh/.test(navigator.userAgent) ? 'Ctrl+Option' : 'Ctrl+Alt';
	const content = `<div class="vocabHelp" lang="en">
		<p>
			Use your keyboard to navigate:<br>
			<b>${meta}+V</b> Turn on/off<br>
			<b>←</b> Show previous definition<br>
			<b>→</b> Show next definition<br>
			<b>Space</b> Show/hide definition<br>
			<b>Esc</b> Turn off
		</p>
		<p>
			<a href="https://techiaith.cymru/cwmwl/ategion/vocab/" lang="cy" hreflang="cy">Gwybodaeth am Vocab</a>
			|
			<a href="https://techiaith.cymru/cloud/widgets/vocab/?lang=en" hreflang="en">About Vocab</a>
		</p>
	</div>`;
	showPopup(target, content);
}
