import { element, deactivateLink, isTouch } from './main.js';
import { computePosition, offset, shift, limitShift, autoPlacement, autoUpdate, arrow }
	from '@floating-ui/dom';

let isOpen = false;
let cleanup = false;
let popupElement, contentElement, arrowElement;

function insertPopup() {
	element.insertAdjacentHTML('beforeend', `
<div class="vocab vocabTip" role="tooltip">
	<a class="vocabButton" name="close" role="button" title="Close"></a>
	<div class="vocabTipContent"></div>
	<div class="vocabArrow"></div>
</div>
`);
	popupElement = element.lastElementChild;
	popupElement.firstElementChild.addEventListener('click', deactivateLink);
	contentElement = popupElement.querySelector('.vocabTipContent');
	arrowElement = popupElement.querySelector('.vocabArrow');
}

export function showPopup(target, content) {
	if (!target) return;
	if (!popupElement) insertPopup();
	if (cleanup) cleanup();

	contentElement.innerHTML = content;
	popupElement.setAttribute('data-show', '');

	cleanup = autoUpdate(target, popupElement, () => {
		computePosition(target, popupElement, {
			placement: 'top',
			middleware: [offset(8), autoPlacement({
				allowedPlacements: ['top', 'bottom'],
			}), shift({
  				limiter: limitShift({
    				// Start limiting 5px earlier
    				//offset: window.offset || -8,
  				}),
			}), arrow({
				element: arrowElement,
			})], //flip(), shift({limiter: limitShift()})],
		}).then(({x, y, placement, middlewareData}) => {
			Object.assign(popupElement.style, {
				left: `${x}px`,
				top: `${y}px`,
			});
			popupElement.dataset.placement = placement;
			if (middlewareData.arrow) {
				const {x: ax, y: ay} = middlewareData.arrow;
				Object.assign(arrowElement.style, {
					left: ax != null ? `${ax}px` : '',
					//top: ay != null ? `${ay}px` : '',
				});
			}
		});
	});
	isOpen = true;
}

export function hidePopup() {
	if (cleanup) cleanup();
	cleanup = false;

	if (popupElement) popupElement.removeAttribute('data-show');
	isOpen = false;
}

export function hasPopup() {
	return isOpen;
}